<?
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
?>
<?
class Abstract_Database {
	var $tablePrefix;

	function setTablePrefix($prefix) {
		$this->tablePrefix = $prefix;
	}

	function prefix($tablename) {
		return $this->tablePrefix . $tablename;
	}

	function query($sql) {
		print "Error: query() should be overridden by a subclass!";
	}

	function fetch_row($results) {
		print "Error: fetch_row() should be overridden by a subclass!";
	}
}
?>