@echo off
del setup\SECURE

echo :
echo : You are now in setup mode, which is *INSECURE*.  Your Gallery
echo : installation can be configured by pointing your web browser
echo : to the URL to 'setup' in this directory.
echo : When you are done with your installation, don't forget to
echo : run the secure.bat script!
echo : 
