@echo off
echo IF THIS FILE EXISTS, YOU CAN'T CONFIGURE GALLERY > setup\SECURE

echo : 
echo : Your Gallery is now secure and cannot be configured.  If
echo : you wish to reconfigure it, run the configure.bat script.
echo : 
